"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const lodash_1 = require("lodash");
const react_1 = __importStar(require("react"));
const styled_1 = __importDefault(require("../styled"));
const Box_1 = require("./Box");
const Icon_1 = require("./Icon");
const initialState = {
    isOpen: false,
};
class ActionDrawer extends react_1.Component {
    constructor() {
        super(...arguments);
        this.state = initialState;
        this.containerRef = react_1.createRef();
        this.handleClick = () => {
            this.handleOpen();
        };
        this.handleClose = () => {
            this.setState({
                isOpen: false,
            }, this.cleanup);
        };
        this.handleOpen = () => {
            this.setState({ isOpen: true });
            document.addEventListener('click', this.handleOutsideClick);
        };
        this.handleOutsideClick = (evt) => {
            if (this.state.isOpen && !this.containerRef.current.contains(evt.target)) {
                this.handleClose();
            }
        };
        this.cleanup = () => {
            document.removeEventListener('click', this.handleOutsideClick);
        };
        this.renderChildren = () => {
            const { children } = this.props;
            if (lodash_1.isArray(children)) {
                return (react_1.default.createElement(react_1.Fragment, null, react_1.Children.map(children, (child, i) => (react_1.default.createElement(Action, { key: i }, child)))));
            }
            return react_1.default.createElement(Action, null, children);
        };
    }
    componentWillUnmount() {
        this.cleanup();
    }
    render() {
        const { children, icon, direction, ...passThroughProps } = this.props;
        const { isOpen } = this.state;
        return (react_1.default.createElement(ActionDrawerContainer, Object.assign({ position: "relative" }, passThroughProps, { onClick: this.handleClick }),
            react_1.default.createElement(Icon_1.Icon, { "data-testid": "action-drawer", name: icon ? icon : 'ellipsis' }),
            isOpen && (react_1.default.createElement(ActionsContainer, { direction: direction, "data-testid": "action-drawer-options", ref: this.containerRef, width: passThroughProps.width }, this.renderChildren()))));
    }
}
ActionDrawer.defaultProps = {
    direction: 'right',
};
exports.ActionDrawer = ActionDrawer;
// Styles
const ActionDrawerContainer = styled_1.default(Box_1.Box) `
  position: relative;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.5rem;
  height: 1.5rem;
  border-radius: 2px;
  ${(props) => props.background && `background: ${props.theme[props.background]};`}
  ${(props) => props.border && `border: 1px solid ${props.theme[props.border]};`}


  &:hover {
    cursor: pointer;
  }
`;
const ActionsContainer = styled_1.default('div') `
  position: absolute;
  top: 2rem;
  ${(p) => p.direction}: 0;
  background: white;
  z-index: 1000;
  width: ${(props) => (props.width ? props.width : '140px')};
  border: 1px solid ${(props) => props.theme.border};
  ${(props) => props.theme.addBoxShadow()};
`;
const Action = styled_1.default.div `
  margin: 0.25rem;
  padding: 0.25rem 0.75rem;
  font-size: 0.8rem;
  font-weight: 700;
  border-radius: 5px;
  &:hover {
    cursor: pointer;
    background: ${(p) => p.theme.n1};
    font-weight: 700;
  }
  border-bottom: 1px solid ${(p) => p.theme.n2};
  :last-child {
    border-bottom: none;
  }
`;
//# sourceMappingURL=ActionDrawer.js.map