"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const common_1 = require("./common");
const paddingTop = {
    className: 'p-tp',
    cssName: 'padding-top'
};
const paddingRight = {
    className: 'p-rt',
    cssName: 'padding-right'
};
const paddingBottom = {
    className: 'p-btm',
    cssName: 'padding-bottom'
};
const paddingLeft = {
    className: 'p-lt',
    cssName: 'padding-left'
};
const paddingEnhancers = {
    paddingTop: (value) => common_1.enhancer(paddingTop, value),
    paddingRight: (value) => common_1.enhancer(paddingRight, value),
    paddingBottom: (value) => common_1.enhancer(paddingBottom, value),
    paddingLeft: (value) => common_1.enhancer(paddingLeft, value)
};
const paddingAliases = {
    padding: (value) => {
        const paddingValues = value.split(' ');
        if ((paddingValues.length > 1 && paddingValues.length % 2 !== 0) || paddingValues.length > 4)
            throw new Error('Margins can only take 1, 2 or 4 values');
        else if (paddingValues.length === 1) {
            return new Map([
                ['paddingTop', paddingValues[0]],
                ['paddingBottom', paddingValues[0]],
                ['paddingRight', paddingValues[0]],
                ['paddingLeft', paddingValues[0]]
            ]);
        }
        else if (paddingValues.length === 2) {
            return new Map([
                ['paddingTop', paddingValues[0]],
                ['paddingBottom', paddingValues[0]],
                ['paddingRight', paddingValues[1]],
                ['paddingLeft', paddingValues[1]]
            ]);
        }
        else {
            return new Map([
                ['paddingTop', paddingValues[0]],
                ['paddingBottom', paddingValues[2]],
                ['paddingRight', paddingValues[1]],
                ['paddingLeft', paddingValues[3]]
            ]);
        }
    },
    paddingX: (value) => {
        return new Map([['paddingLeft', value], ['paddingRight', value]]);
    },
    paddingY: (value) => {
        return new Map([['paddingTop', value], ['paddingBottom', value]]);
    }
};
const marginTop = {
    className: 'm-tp',
    cssName: 'margin-top'
};
const marginRight = {
    className: 'm-rt',
    cssName: 'margin-right'
};
const marginBottom = {
    className: 'm-btm',
    cssName: 'margin-bottom'
};
const marginLeft = {
    className: 'm-lt',
    cssName: 'margin-left'
};
const marginEnhancers = {
    marginTop: (value) => common_1.enhancer(marginTop, value),
    marginRight: (value) => common_1.enhancer(marginRight, value),
    marginBottom: (value) => common_1.enhancer(marginBottom, value),
    marginLeft: (value) => common_1.enhancer(marginLeft, value)
};
const marginAliases = {
    margin: (value) => {
        const marginValues = value.split(' ');
        if ((marginValues.length > 1 && marginValues.length % 2 !== 0) || marginValues.length > 4)
            throw new Error('Margins can only take 1, 2 or 4 values');
        else if (marginValues.length === 1) {
            return new Map([
                ['marginTop', marginValues[0]],
                ['marginBottom', marginValues[0]],
                ['marginRight', marginValues[0]],
                ['marginLeft', marginValues[0]]
            ]);
        }
        else if (marginValues.length === 2) {
            return new Map([
                ['marginTop', marginValues[0]],
                ['marginBottom', marginValues[0]],
                ['marginRight', marginValues[1]],
                ['marginLeft', marginValues[1]]
            ]);
        }
        else {
            return new Map([
                ['marginTop', marginValues[0]],
                ['marginBottom', marginValues[2]],
                ['marginRight', marginValues[1]],
                ['marginLeft', marginValues[3]]
            ]);
        }
    },
    marginX: (value) => {
        return new Map([['marginLeft', value], ['marginRight', value]]);
    },
    marginY: (value) => {
        return new Map([['marginTop', value], ['marginBottom', value]]);
    }
};
exports.spacingEnhancers = {
    ...paddingEnhancers,
    ...marginEnhancers
};
exports.spacingAliases = {
    ...paddingAliases,
    ...marginAliases
};
//# sourceMappingURL=spacing.js.map