"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const cache = __importStar(require("./cache"));
const enhancers_1 = require("./enhancers");
const styleSheet_1 = __importDefault(require("./styleSheet"));
// @ts-ignore
const styleSheet = new styleSheet_1.default();
exports.Box = ({ is = 'div', children, className = '', onClick = null, type = null, 'data-testid': dataTestId, 'data-for': dataFor, 'data-tip': dataTip, ...props }) => {
    const propMap = toPropMap(props);
    let classes = className;
    for (const [propName, propValue] of propMap) {
        // Check if we've cached it
        const cachedValue = cache.get(`${propName} ${propValue}`);
        const enhancer = enhancers_1.enhancers[propName];
        if (!enhancer) {
            if (process.env.DEBUG_BOX)
                throw new Error(`Whoops, we haven't implemented an enhancer for ${propName} yet`);
            continue;
        }
        else {
            // Add to Cache
            if (!cachedValue) {
                const { styleName, rule } = enhancer(propValue);
                cache.add(propName, propValue, styleName);
                // Write the class to stylesheet
                styleSheet.insertRule(rule);
                classes = `${classes} ${cache.get(`${propName} ${propValue}`)}`;
            }
            else {
                classes = `${classes} ${cachedValue}`;
            }
        }
    }
    // prettier-ignore
    const enhancedProps = { 'className': classes, 'data-testid': dataTestId, 'data-tip': dataTip, 'data-for': dataFor, onClick, type };
    return react_1.createElement(is, enhancedProps, children);
};
// Turn the props into a Map
function toPropMap(props) {
    const propNames = Object.keys(props);
    const propMap = new Map();
    propNames.forEach((propName) => {
        // Get any aliased css class names
        const aliasFunc = enhancers_1.aliases[propName];
        if (aliasFunc) {
            for (const [name, value] of aliasFunc(props[propName])) {
                propMap.set(name, value);
            }
        }
        else {
            propMap.set(propName, props[propName]);
        }
    });
    return propMap;
}
exports.toPropMap = toPropMap;
//# sourceMappingURL=index.js.map