"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const downshift_1 = __importDefault(require("downshift"));
const react_1 = __importDefault(require("react"));
const Icon_1 = require("../components/Icon");
const styled_1 = __importDefault(require("../styled"));
const themes_1 = require("../themes");
const Box_1 = require("./Box");
exports.Combobox = ({ items, onChange, openOnFocus = true, placeholder, width = '200px', ...props }) => {
    return (react_1.default.createElement(downshift_1.default, { onChange: (selected) => onChange(selected.value), itemToString: (item) => (item ? item.label : '') }, ({ getInputProps, getItemProps, getMenuProps, getToggleButtonProps, inputValue, isOpen, highlightedIndex, selectedItem, toggleMenu, }) => (react_1.default.createElement("div", null,
        react_1.default.createElement(Box_1.Box, Object.assign({}, props, { width: width, display: "flex" }),
            react_1.default.createElement(Input, Object.assign({}, getInputProps({
                placeholder,
                onClick() {
                    if (openOnFocus) {
                        toggleMenu();
                    }
                },
            }))),
            react_1.default.createElement(Button, Object.assign({}, getToggleButtonProps()),
                react_1.default.createElement(Icon_1.Icon, { name: "caretDown" }))),
        isOpen ? (react_1.default.createElement(ListWrapper, Object.assign({}, getMenuProps({ width })), items
            .filter((item) => !inputValue || item.label.toLowerCase().includes(inputValue.toLowerCase()))
            .map((item, index) => (react_1.default.createElement(ListItemWrapper, Object.assign({ highlighted: highlightedIndex === index }, getItemProps({
            key: item.value,
            index,
            item,
        })),
            selectedItem === item ? (react_1.default.createElement(Icon_1.Icon, { name: "checkmark", height: "1.5rem", width: "1.5rem", marginTop: "0.4rem", marginLeft: "0.1rem", marginRight: "0.1rem" })) : (react_1.default.createElement(Unselected, null)),
            react_1.default.createElement(ListItem, null, item.label)))))) : null))));
};
const Button = styled_1.default.button `
  background-color: rgb(236, 239, 240);
  border: 1px solid ${themes_1.theme.n5};
  border-bottom-right-radius: 5px;
  border-top-right-radius: 5px;
  box-sizing: border-box;
  margin-left: -1px;

  :hover {
    background-color: rgb(225, 229, 232);
    cursor: pointer;
  }

  :focus {
    outline: none;
    background-color: rgb(225, 229, 232);
  }
`;
const Input = styled_1.default.input `
  border: 1px solid ${themes_1.theme.n5};
  border-top-left-radius: 5px;
  border-bottom-left-radius: 5px;
  box-shadow: inset 0px 1px 2px ${themes_1.theme.n2};
  box-sizing: border-box;
  flex-grow: 2;
  padding: 0.5rem 0.5rem;

  :focus {
    border: 2px solid ${themes_1.theme.n5};
    outline: none;
    z-index: 2;
  }
`;
const ListItem = styled_1.default('div') `
  border-bottom: 1px solid ${themes_1.theme.n2};
  flex-grow: 2;
  padding: 7px 0px 7px 0px;
  text-overflow: ellipsis;
  overflow: hidden;
  white-space: nowrap;
`;
// prettier-ignore
const ListItemWrapper = styled_1.default('div') `
  background-color: ${(props) => (props.highlighted ? themes_1.theme.n2 : '#FFFFFF')};
  display: flex;

  :last-child div {
    border-bottom: none;
  }
`;
// prettier-ignore
const ListWrapper = styled_1.default('div') `
  box-sizing: border-box;
  box-shadow: 0px 0px 1px ${themes_1.theme.background}, 0px 8px 10px -4px ${themes_1.theme.background};
  border: 1px solid ${themes_1.theme.n2};
  border-radius: 5px;
  display: flex;
  flex-direction: column;
  margin-top: 0.5rem;
  position: absolute;
  overflow: hidden;
  width: ${(props) => props.width || '280px'};
`;
const Unselected = styled_1.default.div `
  padding-left: 30px;
`;
//# sourceMappingURL=Combobox.js.map