import React, { Component, ReactElement, ReactNode } from 'react';
import { BoxProps } from '../Box';
/**
 * The configuration for a single column in the DataTable.
 *
 *  === MetaInfo ===
 *  name:
 *    The name of this column
 *
 *  === Styling ===
 *  size:
 *    The size of the column (defaults to '1fr')
 *  justify:
 *    How to justify contents in the column along the inline (row) axis (defaults to 'start')
 *  align:
 *    How to align contents in the column along the block (column) axis (defaults to 'start')
 *
 *  === User interactions ===
 *  sort:
 *    If provided, this column is sortable. If provided as `true`,
 *    sorts on the row by the 'name' key. If provided as a function, the
 *    returned value will be used to sort the column.
 *
 *  === Rendering ===
 *  modifyHeader:
 *    A function that takes in the default header and customizes
 *    it if desired. If not provided, simply display the header unchanged.
 *
 *  text:
 *    If provided, renders text within a 'span' tag. If a string,
 *    renders the value provided at the given key. If a function, renders
 *    the value returned by the function. If neither 'render' nor 'text' is
 *    provided, sets 'text' to the value of 'name'.
 *  render:
 *    A function that returns an arbitrary ReactNode to display as the
 *    column
 */
export declare type DataTableColumnDef<T> = {
    name: string;
    size?: string;
    justify?: 'start' | 'end' | 'center' | 'stretch';
    align?: 'start' | 'end' | 'center' | 'stretch';
    sort?: boolean | ((row: T) => any);
    modifyHeader?: (header: ReactElement) => ReactElement;
    text?: string | ((row: T) => any);
    render?: (row: T) => ReactNode;
};
export declare type DataTableColumnDefs<T> = Array<DataTableColumnDef<T>>;
declare type Props<T> = {
    data: T[];
    rowKey?: string | ((row: T) => any);
    rowProps?: (row: T) => object;
    columnDefs: DataTableColumnDefs<T>;
} & BoxProps;
declare type State<T> = {
    sort: {
        ascending: boolean;
        index?: number;
    };
};
export declare class DataTable<T> extends Component<Props<T>, State<T>> {
    static TableRow: import("styled-components").StyledComponent<"div", import("../../themes/ThemeInterface").default, {
        className: "data-table-row";
    }, "className">;
    state: {
        sort: {
            ascending: boolean;
            index: number;
        };
    };
    renderRow: (columnDef: DataTableColumnDef<T>, rowData: T) => React.ReactNode;
    getKey: (rowData: T, i: number) => any;
    getSortFn: (columnDef: DataTableColumnDef<T>) => (row: T) => any;
    isSortable: ({ sort }: DataTableColumnDef<T>) => boolean;
    getSortedData: () => T[];
    handleSort: (i: number) => void;
    render(): JSX.Element;
}
export {};
//# sourceMappingURL=index.d.ts.map