"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const lodash_1 = require("lodash");
const react_1 = __importStar(require("react"));
const Icon_1 = require("../Icon");
const Styles_1 = require("./Styles");
const initialState = {
    sort: {
        ascending: false,
        index: null
    }
};
class DataTable extends react_1.Component {
    constructor() {
        super(...arguments);
        this.state = initialState;
        this.renderRow = (columnDef, rowData) => {
            const { name, text, render } = columnDef;
            if (render) {
                return render(rowData);
            }
            let getContents;
            if (typeof text === 'string') {
                getContents = (row) => row[text];
            }
            else if (typeof text === 'function') {
                getContents = text;
            }
            else {
                getContents = (row) => row[name];
            }
            return react_1.default.createElement("span", null, getContents(rowData));
        };
        this.getKey = (rowData, i) => {
            const { rowKey } = this.props;
            if (!rowKey) {
                return i;
            }
            else if (typeof rowKey === 'string') {
                return rowData[rowKey];
            }
            else {
                return rowKey(rowData);
            }
        };
        this.getSortFn = (columnDef) => {
            const { name, sort } = columnDef;
            if (sort === true) {
                return (row) => row[name];
            }
            else if (typeof sort === 'function') {
                return sort;
            }
            else {
                throw new Error('Column definition is not sortable: ' + columnDef);
            }
        };
        this.isSortable = ({ sort }) => sort === true || typeof sort === 'function';
        this.getSortedData = () => {
            const { data, columnDefs } = this.props;
            const { sort } = this.state;
            if (sort.index === null)
                return data;
            const columnDef = columnDefs[sort.index];
            const sortFn = this.getSortFn(columnDef);
            // hack to get types working
            const orderData = lodash_1.orderBy;
            return orderData(data, sortFn, sort.ascending ? 'asc' : 'desc');
        };
        this.handleSort = (i) => {
            if (i === this.state.sort.index) {
                this.setState((prev) => ({
                    sort: {
                        index: i,
                        ascending: !prev.sort.ascending
                    }
                }));
            }
            else {
                const columnDef = this.props.columnDefs[i];
                if (!this.isSortable(columnDef))
                    return;
                this.setState({
                    sort: {
                        index: i,
                        ascending: false
                    }
                });
            }
        };
    }
    render() {
        const { sort } = this.state;
        const { data, rowProps, columnDefs, ...passThroughProps } = this.props;
        const sortedData = this.getSortedData();
        return (react_1.default.createElement(Styles_1.DataTableContainer, Object.assign({ columnSizes: columnDefs.map(({ size }) => size || '1fr').join(' ') }, passThroughProps),
            react_1.default.createElement(Styles_1.DataTableHeaderRow, null, columnDefs.map((columnDef, i) => {
                const { name, modifyHeader } = columnDef;
                const sortIcon = sort.index === i && react_1.default.createElement(Icon_1.Icon, { name: sort.ascending ? 'caretDown' : 'caretUp' });
                const header = (react_1.default.createElement(Styles_1.DataTableHeader, { key: i, size: "fs300", color: "n5", weight: "fwBold", textTransform: "uppercase", display: "flex", alignItems: "center", onClick: () => this.handleSort(i) },
                    lodash_1.startCase(name),
                    sortIcon));
                if (modifyHeader) {
                    return modifyHeader(header);
                }
                else {
                    return header;
                }
            })),
            sortedData.map((rowData, i) => (react_1.default.createElement(Styles_1.DataTableRow, Object.assign({ key: this.getKey(rowData, i) }, (rowProps && rowProps(rowData))), columnDefs.map((columnDef, j) => {
                const child = this.renderRow(columnDef, rowData);
                // need to set 'key' attribute so react doesn't
                // complain, even though 'columnDefs' is a static list
                return (react_1.default.createElement(Styles_1.DataTableCell, { justify: columnDef.justify || 'start', align: columnDef.align || 'center', key: j }, child));
            }))))));
    }
}
DataTable.TableRow = Styles_1.DataTableRow;
exports.DataTable = DataTable;
//# sourceMappingURL=index.js.map