"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const lodash_1 = require("lodash");
const react_1 = __importStar(require("react"));
const Button_1 = require("../Button");
const Typography_1 = require("../Typography");
const Dialog_1 = __importDefault(require("./Dialog"));
const Styles_1 = require("./Styles");
const initialState = {
    isOpen: false
};
class SimpleDialog extends react_1.Component {
    constructor() {
        super(...arguments);
        this.state = initialState;
        this.handleOpen = () => this.setState({
            isOpen: true
        });
        this.handleConfirm = async () => {
            if (this.props.onConfirm) {
                this.props.onConfirm();
            }
            this.handleClose();
        };
        this.handleCancel = async () => {
            if (this.props.onCancel) {
                this.props.onCancel();
            }
            this.handleClose();
        };
        this.handleClose = () => this.setState({
            isOpen: false
        });
        this.renderTrigger = () => {
            const { customTrigger, triggerLabel } = this.props;
            return customTrigger ? (react_1.cloneElement(customTrigger, {
                onClick: this.handleOpen,
                style: {
                    cursor: 'pointer'
                }
            })) : (react_1.default.createElement(Button_1.Button, { onClick: this.handleOpen, "data-testid": lodash_1.kebabCase(triggerLabel) || 'button', primary: this.props.buttonType === 'primary' || !this.props.buttonType ? true : false, success: this.props.buttonType === 'success' ? true : false, warning: this.props.buttonType === 'warning' ? true : false, danger: this.props.buttonType === 'danger' ? true : false }, triggerLabel || 'Open'));
        };
    }
    componentDidMount() {
        if (this.props.shouldCloseOnClickOverlay) {
            document.addEventListener('keydown', (event) => this.onKeyDown(event));
        }
    }
    componentWillUnmount() {
        if (this.props.shouldCloseOnClickOverlay) {
            document.removeEventListener('keydown', (event) => this.onKeyDown(event));
        }
    }
    onKeyDown(event) {
        if (event.keyCode === 27) {
            this.handleClose();
        }
    }
    render() {
        const { title, children, cancelLabel, confirmLabel, onCancel, onConfirm, shouldCloseOnClickOverlay, hasCancel, hasConfirm, triggerLabel, ...passThroughProps } = this.props;
        return (react_1.default.createElement(react_1.Fragment, null,
            this.renderTrigger(),
            this.state.isOpen && (react_1.default.createElement(Dialog_1.default, Object.assign({ isOpen: this.state.isOpen, onCancel: this.handleCancel, shouldCloseOnClickOverlay: shouldCloseOnClickOverlay }, passThroughProps),
                title && (react_1.default.createElement(Styles_1.DialogHeader, { "data-testid": "dialog-header" },
                    react_1.default.createElement(Typography_1.Heading, { color: "n7" }, title))),
                react_1.default.createElement(Dialog_1.default.Body, null, children),
                (hasCancel || hasConfirm) && (react_1.default.createElement(Dialog_1.default.Footer, { "data-testid": "dialog-footer" },
                    react_1.default.createElement(Styles_1.DialogFooterButtons, null,
                        hasCancel && (react_1.default.createElement(Button_1.Button, { onClick: this.handleCancel, "data-testid": "dialog-cancel", marginRight: "1rem" }, cancelLabel)),
                        hasConfirm && (react_1.default.createElement(Button_1.Button, { onClick: this.handleConfirm, "data-testid": "dialog-confirm", primary: this.props.confirmButtonType === 'primary' ? true : false, success: this.props.confirmButtonType === 'success' || !this.props.confirmButtonType ? true : false }, confirmLabel)))))))));
    }
}
SimpleDialog.defaultProps = {
    shouldCloseOnClickOverlay: true,
    cancelLabel: 'Cancel',
    confirmLabel: 'Confirm',
    hasCancel: true,
    hasConfirm: true
};
exports.default = SimpleDialog;
//# sourceMappingURL=SimpleDialog.js.map