"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const formik_1 = require("formik");
const react_1 = __importStar(require("react"));
const styled_1 = __importDefault(require("../../styled"));
const Box_1 = require("../Box");
const Typography_1 = require("../Typography");
const Styles_1 = require("./Styles");
const BaseFormField = ({ name, label, description, children, ...passThroughProps }) => (react_1.default.createElement(Wrapper, Object.assign({}, passThroughProps),
    label && react_1.default.createElement(Styles_1.Label, { htmlFor: name }, label),
    description && (react_1.default.createElement(Typography_1.Text, { size: "fs400", color: "n5" }, description)),
    children));
exports.FormErrorMessage = ({ name }) => (react_1.default.createElement(formik_1.ErrorMessage, { name: name }, (msg) => (react_1.default.createElement(Typography_1.Text, { size: "fs400", color: "r6" }, msg))));
/**
 * The base component for any Formik field.
 *
 * Usage:
 *
 *     <FormField
 *       name="name"
 *       label="Table Name"
 *       render={({ field, form }) => { ... }}
 *     />
 */
const FormField = ({ name, render, noError, ...passThroughProps }) => (react_1.default.createElement(BaseFormField, Object.assign({ name: name }, passThroughProps),
    react_1.default.createElement(formik_1.Field, { name: name }, (fieldProps) => {
        return (react_1.default.createElement(react_1.Fragment, null,
            render(fieldProps),
            !noError && react_1.default.createElement(exports.FormErrorMessage, { name: name })));
    })));
exports.default = FormField;
/**
 * The base component for an array of Formik fields.
 *
 * Usage:
 *
 *     <FormFieldArray
 *       name="name"
 *       label="Table Name"
 *       render={({ push, remove }) => { ... }}
 *     />
 */
exports.FormFieldArray = ({ name, render, ...passThroughProps }) => (react_1.default.createElement(BaseFormField, Object.assign({ name: name }, passThroughProps),
    react_1.default.createElement(formik_1.FieldArray, { name: name, render: render })));
const Wrapper = styled_1.default(Box_1.Box) `
  margin: ${(props) => {
    if (props.margin) {
        return props.margin;
    }
    else if (props.marginTop || props.marginRight || props.marginLeft || props.marginBottom) {
        return `${props.marginTop || 0} ${props.marginRight || 0} ${props.marginBottom || 0} ${props.marginLeft || 0}`;
    }
    else {
        return '0.5rem 0';
    }
}};

  :first-child {
    margin-top: 0;
  }

  :last-child {
    margin-bottom: 0;
  }
`;
//# sourceMappingURL=FormField.js.map