"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importStar(require("react"));
const react_dropzone_1 = __importDefault(require("react-dropzone"));
const styled_1 = __importDefault(require("../../styled"));
const Typography_1 = require("../Typography");
const FormField_1 = __importDefault(require("./FormField"));
const Textarea_1 = __importDefault(require("./Textarea"));
/**
 * Displays a form field for uploading files.
 *
 * Currently, sets the Formik field to the contents of the file and displays the contents of the file,
 * but we might want to make this customizable later
 */
const FormFileUpload = ({ name, 'data-testid': dataTestId, ...passThroughProps }) => (react_1.default.createElement(FormField_1.default, Object.assign({ name: name }, passThroughProps, { render: ({ field, form }) => {
        const { setFieldError, setFieldTouched, setFieldValue } = form;
        const onDrop = (acceptedFiles) => {
            const file = acceptedFiles[0];
            const reader = new FileReader();
            reader.onload = () => {
                setFieldTouched(name, true);
                setFieldValue(name, reader.result.trim());
            };
            reader.onerror = (e) => {
                console.error(e);
                setFieldError(name, 'Could not upload file');
            };
            reader.readAsText(file);
        };
        const id = dataTestId || name;
        return (react_1.default.createElement(react_1.Fragment, null,
            react_1.default.createElement(react_dropzone_1.default, { multiple: false, onDrop: onDrop }, ({ getRootProps, getInputProps, isDragActive }) => (react_1.default.createElement(DropTarget, Object.assign({ active: isDragActive, "data-testid": `${id}-dropzone` }, getRootProps()),
                react_1.default.createElement("input", Object.assign({}, getInputProps())),
                react_1.default.createElement(Typography_1.Text, { size: "fs400", color: "n4", fontWeight: "fwBold" }, "Drag/drop file here or click to select file")))),
            field.value !== '' && react_1.default.createElement(FilePreview, Object.assign({ disabled: true, "data-testid": id }, field))));
    } })));
exports.default = FormFileUpload;
const DropTarget = styled_1.default('div') `
  margin: 10px 0;
  padding: 10px 20px;

  background: ${(p) => p.theme.background};
  ${(p) => p.active &&
    `
    background: ${p.theme.n2};
  `}
  border: 3px dashed ${(p) => p.theme.border};
  outline: 0;

  text-align: center;
  cursor: pointer;
`;
const FilePreview = styled_1.default(Textarea_1.default) `
  white-space: pre;
`;
//# sourceMappingURL=FormFileUpload.js.map