"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importStar(require("react"));
const styled_1 = __importDefault(require("../../styled"));
// Pulling values from theme directly because <Toaster /> renders to a node outside of the <Providers></Providers>
const themes_1 = require("../../themes");
const BaseTheme_1 = require("../BaseTheme");
const Icon_1 = require("../Icon");
class Toaster extends react_1.Component {
    constructor() {
        super(...arguments);
        this.closeTimer = null;
        this.startTimer = () => {
            this.closeTimer = setTimeout(() => {
                this.props.onRemove(this.props.id);
            }, this.props.duration);
        };
        this.handleClick = () => {
            if (!this.props.onClose)
                return;
            this.props.onClose(this.props.id);
        };
    }
    componentDidMount() {
        if (this.props.duration) {
            this.startTimer();
        }
    }
    componentDidUpdate(prevProps) {
        if (prevProps.isVisible !== this.props.isVisible) {
            this.props.onRemove(this.props.id);
        }
    }
    render() {
        const { id, type, children, style } = this.props;
        // TODO: Triggered toasts don't render color because toasts are being rendered outside App / theme
        const renderIcon = () => {
            if (type === 'warning') {
                return react_1.default.createElement(Icon_1.Icon, { name: "warning", color: "y6", marginRight: "12px" });
            }
            else if (type === 'error') {
                return react_1.default.createElement(Icon_1.Icon, { name: "error", color: "r5", marginRight: "12px" });
            }
            else if (type === 'success') {
                return react_1.default.createElement(Icon_1.Icon, { name: "success", color: "g5", marginRight: "12px" });
            }
            else {
                return react_1.default.createElement(Icon_1.Icon, { name: "info", color: "b9", marginRight: "12px" });
            }
        };
        return (react_1.default.createElement(BaseTheme_1.BaseTheme, null,
            react_1.default.createElement(ToastContainer, { type: type, style: style, "data-testid": `toast-${type}` },
                renderIcon(),
                children,
                react_1.default.createElement(IconWrapper, { onClick: this.handleClick, "data-testid": `close-toast-${id}` },
                    react_1.default.createElement(Icon_1.Icon, { name: "cancel", height: "1rem", width: "0.8rem" })))));
    }
}
exports.default = Toaster;
const ToastContainer = styled_1.default('div') `
  display: grid;
  grid-template-columns: auto 1fr 20px;
  padding: 0.5rem 1rem 0.5rem 1rem;
  align-items: center;
  margin-bottom: 1rem;
  width: 100%;
  border: 1px solid ${themes_1.theme.border};
  border-left: 4px solid;
  border-radius: 3px;
  background: white;
  box-shadow: 0px 4px 8px rgba(0, 0, 0, 0.2);
  pointer-events: all;
  ${(p) => {
    switch (p.type) {
        case 'warning':
            return `border-left-color: ${themes_1.theme.y6}; color:  ${themes_1.theme.y6};`;
        case 'error':
            return `border-left-color: ${themes_1.theme.r5}; color:  ${themes_1.theme.r5};`;
        case 'success':
            return `border-left-color: ${themes_1.theme.g5}; color:  ${themes_1.theme.g5};`;
        default:
            return `border-left-color: ${themes_1.theme.b9}; color:  ${themes_1.theme.b9};`;
    }
}}
`;
const IconWrapper = styled_1.default('span') `
  ${themes_1.theme.addHover()};
  margin-right: -10px;
`;
//# sourceMappingURL=Toast.js.map