"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const react_router_dom_1 = require("react-router-dom");
const react_tooltip_1 = __importDefault(require("react-tooltip"));
const styled_1 = __importDefault(require("../styled"));
const Box_1 = require("./Box");
exports.Text = ({ children, href = '', linkTo = '', size = 'fs500', truncate, weight = 'fwNormal', ...props }) => {
    if (linkTo.length > 0) {
        if (truncate) {
            return (react_1.default.createElement(react_router_dom_1.Link, { to: linkTo },
                react_1.default.createElement(StyledText, Object.assign({ fontSize: size, fontWeight: weight, "data-tip": true, "data-for": children.toString(), textOverflow: "ellipsis", overflow: "hidden", whiteSpace: "nowrap", hoverable: true }, props),
                    children,
                    react_1.default.createElement(react_tooltip_1.default, { id: children.toString(), className: "tooltip", delayShow: 500, effect: "solid" }, children))));
        }
        else {
            return (react_1.default.createElement(react_router_dom_1.Link, { to: linkTo },
                react_1.default.createElement(StyledText, Object.assign({ fontSize: size, fontWeight: weight, hoverable: true }, props), children)));
        }
    }
    else if (href.length > 0) {
        if (truncate) {
            return (react_1.default.createElement(StyledText, Object.assign({ fontSize: size, fontWeight: weight, "data-tip": true, "data-for": children.toString(), textOverflow: "ellipsis", overflow: "hidden", whiteSpace: "nowrap", hoverable: true }, props),
                react_1.default.createElement("a", { href: href }, children),
                react_1.default.createElement(react_tooltip_1.default, { id: children.toString(), className: "tooltip", delayShow: 500, effect: "solid" }, children)));
        }
        else {
            return (react_1.default.createElement(StyledText, Object.assign({ fontSize: size, fontWeight: weight, hoverable: true }, props),
                react_1.default.createElement("a", { href: href }, children)));
        }
    }
    else {
        if (truncate) {
            return (react_1.default.createElement(StyledText, Object.assign({ fontSize: size, fontWeight: weight, "data-tip": true, "data-for": children.toString(), textOverflow: "ellipsis", overflow: "hidden", whiteSpace: "nowrap" }, props),
                children,
                react_1.default.createElement(react_tooltip_1.default, { id: children.toString(), className: "tooltip", delayShow: 500, effect: "solid" }, children)));
        }
        else {
            return (react_1.default.createElement(StyledText, Object.assign({ fontSize: size, fontWeight: weight }, props), children));
        }
    }
};
exports.Heading = ({ size = 'hd6', children, truncate, ...props }) => {
    if (truncate) {
        return (react_1.default.createElement(StyledHeading, Object.assign({ size: size, "data-tip": true, "data-for": children.toString(), textOverflow: "ellipsis", overflow: "hidden", whiteSpace: "nowrap" }, props),
            children,
            react_1.default.createElement(react_tooltip_1.default, { id: children.toString(), className: "tooltip", delayShow: 500, effect: "solid" }, children)));
    }
    else {
        return (react_1.default.createElement(StyledHeading, Object.assign({ size: size }, props), children));
    }
};
// prettier-ignore
const SharedStyles = styled_1.default(Box_1.Box) `
  .tooltip {
    font-size: 0.75rem !important;
    font-weight: normal;
    color: ${(props) => props.theme.n8} !important;
    background-color: ${(props) => props.theme.n1} !important;
    padding: 0.5rem !important;
    min-width: 4rem;
    text-align: center;
    &.place-top {
      &:after {
        border-top-color: ${(props) => props.theme.n1} !important;
        border-top-style: solid !important;
        border-top-width: 6px !important;
      }
    }

    &.place-bottom {
      &:after {
        border-bottom-color: ${(props) => props.theme.n1} !important;
        border-bottom-style: solid !important;
        border-bottom-width: 6px !important;
      }
    }

    &.place-left {
      &:after {
        border-left-color: ${(props) => props.theme.n1} !important;
        border-left-style: solid !important;
        border-left-width: 6px !important;
      }
    }

    &.place-right {
      &:after {
        border-right-color: ${(props) => props.theme.n1} !important;
        border-right-style: solid !important;
        border-right-width: 6px !important;
      }
    }
  }
`;
const StyledHeading = styled_1.default(SharedStyles) `
  font-size: ${(props) => props.theme[props.size]};
  font-weight: bold;
`;
const StyledText = styled_1.default(SharedStyles) `
  ${(p) => p.hoverable && p.theme.addHover()}
`;
//# sourceMappingURL=Typography.js.map